summaryrefslogtreecommitdiffstats
path: root/kandy/src/kandy.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/kandy.cpp')
-rw-r--r--kandy/src/kandy.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kandy/src/kandy.cpp b/kandy/src/kandy.cpp
index 95bf20ac..4766947a 100644
--- a/kandy/src/kandy.cpp
+++ b/kandy/src/kandy.cpp
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <tqlineedit.h>
@@ -175,7 +175,7 @@ void Kandy::dragEnterEvent(TQDragEnterEvent *event)
void Kandy::dropEvent(TQDropEvent *event)
{
// this is a very simplistic implementation of a drop event. we
// will only accept a dropped URL. the Qt dnd code can do *much*
// much more, so please read the docs there
// do nothing
@@ -227,7 +227,7 @@ void Kandy::filePrint()
if (!mPrinter) mPrinter = new TQPrinter;
if (TQPrintDialog::getPrinterSetup(mPrinter))
{
// setup the printer. with Qt, you always "print" to a
// TQPainter.. whether the output medium is a pixmap, a screen,
// or paper
TQPainter p;
@@ -300,7 +300,7 @@ bool Kandy::queryClose()
{
if (mView->isModified()) {
switch (KMessageBox::warningYesNoCancel(this,
- i18n("Save changes to profile %1?").arg(mFilename), TQString::null, KStdGuiItem::save(), KStdGuiItem::discard())) {
+ i18n("Save changes to profile %1?").arg(mFilename), TQString(), KStdGuiItem::save(), KStdGuiItem::discard())) {
case KMessageBox::Yes :
fileSave();
return true;
@@ -318,7 +318,7 @@ void Kandy::modemConnect()
{
if (!mScheduler->modem()->open()) {
KMessageBox::sorry(this,
- i18n("Cannot open modem device %1.")
+ i18n("Cannot open modem tqdevice %1.")
.arg(KandyPrefs::serialDevice()), i18n("Modem Error"));
return;
}
@@ -175,7 +175,7 @@ void Kandy::dragEnterEvent(TQDragEnterEvent *event)
{
// this is a very simplistic implementation of a drop event. we
- // will only accept a dropped URL. the Qt dnd code can do *much*
+ // will only accept a dropped URL. the TQt dnd code can do *much*
// much more, so please read the docs there
// do nothing
@@ -227,7 +227,7 @@ void Kandy::filePrint()
if (TQPrintDialog::getPrinterSetup(mPrinter))
{
- // setup the printer. with Qt, you always "print" to a
+ // setup the printer. with TQt, you always "print" to a
// TQPainter.. whether the output medium is a pixmap, a screen,
// or paper